@@ -3,6 +3,7 @@ import argparse
 import sys
 import os
 from typing import Sequence
+import configparser
 
 from ai_commit_msg.cli.config_handler import config_handler, handle_config_setup
 from ai_commit_msg.cli.gen_ai_commit_message_handler import gen_ai_commit_message_handler
@@ -14,6 +15,11 @@ from ai_commit_msg.utils.logger import Logger
 def called_from_git_hook():
     return os.environ.get('PRE_COMMIT') == '1'
 
+def get_version():
+    config = configparser.ConfigParser()
+    config.read('setup.cfg')
+    return config['metadata']['version']
+
 def main(argv: Sequence[str] = sys.argv[1:]) -> int:
     if called_from_git_hook():
         return prepare_commit_msg_hook()
@@ -26,6 +32,7 @@ def main(argv: Sequence[str] = sys.argv[1:]) -> int:
         return gen_ai_commit_message_handler()
 
     parser = argparse.ArgumentParser(description="🚀 AI-powered CLI tool that revolutionizes your Git workflow by automatically generating commit messages!")
+    parser.add_argument('-v', '--version', action='version', version=f'%(prog)s {get_version()}')
     subparsers = parser.add_subparsers(dest='command', required=False)
 
     # Config command
@@ -36,16 +43,16 @@ def main(argv: Sequence[str] = sys.argv[1:]) -> int:
     config_parser.add_argument('-m', '--model',help= '🧠 Set the OpenAI model to use for generating commit messages')
     config_parser.add_argument('-ou', '--ollama-url', help='🌐 Set the Ollama URL for local LLM models')
     config_parser.add_argument('-a', '--anthropic-key', dest='anthropic_key', help='🔑 Set your Anthropic API key for AI-powered commit messages')
-    config_parser.add_argument('-as', '--setup', action='store_true', help='🔧 Setup the tool')
-
+    config_parser.add_argument('-s', '--setup', action='store_true', help='🔧 Setup the tool')
+    config_parser.add_argument('-p', '--prefix', help='🏷️ Set a prefix for the commit message')
     # Help command
     subparsers.add_parser('help', help='Display this help message')
 
     # Hook command
     hook_parser = subparsers.add_parser('hook', help='🪝 Run the prepare-commit-msg hook to generate commit messages')
-    hook_parser.add_argument('--setup', action='store_true', help='Setup the prepare-commit-msg hook')
-    hook_parser.add_argument('--remove', action='store_true', help='Remove the prepare-commit-msg hook')
-    hook_parser.add_argument('--run', action='store_true', help='Run the prepare-commit-msg hook')
+    hook_parser.add_argument('-s','--setup', action='store_true', help='Setup the prepare-commit-msg hook')
+    hook_parser.add_argument('-r','--remove', action='store_true', help='Remove the prepare-commit-msg hook')
+    hook_parser.add_argument('-x','--run', action='store_true', help='Run the prepare-commit-msg hook')
     args = parser.parse_args(argv)
 
     if args.command == 'config':
